read_are

Function read_are 

pub fn read_are<R: Read>(reader: &mut R) -> Result<Are, AreError>
Reads typed ARE data from a reader at the current stream position.

Errors

AreError::Gff when the stream is not a readable GFF, and AreError::UnsupportedFileType when it is a GFF of some other format, carrying the fourcc that was found.