pub struct Dlg {Show 17 fields
pub camera_model: ResRef,
pub delay_entry: u32,
pub delay_reply: u32,
pub end_conversation: ResRef,
pub end_conver_abort: ResRef,
pub skippable: bool,
pub conversation_type: i32,
pub computer_type: u8,
pub ambient_track: ResRef,
pub unequip_items: bool,
pub unequip_h_item: bool,
pub animated_cut: bool,
pub old_hit_check: bool,
pub starting_list: Vec<DlgLink>,
pub entries: Vec<DlgNode>,
pub replies: Vec<DlgNode>,
pub stunt_list: Vec<DlgStunt>,
}Expand description
Typed DLG model built from/to Gff data.
Fields
camera_model: ResRefCamera model resref (CameraModel).
delay_entry: u32Delay before entry lines in ms (DelayEntry). If missing, safely defaults to 0.
delay_reply: u32Delay before reply lines in ms (DelayReply). If missing, safely defaults to 0.
end_conversation: ResRefEnd-conversation script (EndConversation). Fallback to empty string "" if missing.
end_conver_abort: ResRefEnd-conversation-abort script (EndConverAbort). Fallback to empty string "" if missing.
skippable: boolSkippable flag (Skippable). Explicitly defaults to 1 (True) if missing.
conversation_type: i32Conversation type (ConversationType). 0 = Cinematic, 1 = Computer, 2 = Special. The Cinematic variant explicitly unstealths the entire party at runtime.
computer_type: u8Computer type (ComputerType). Ignored by engine unless ConversationType is 1.
ambient_track: ResRefAmbient music track (AmbientTrack). Fallback to empty string "" if missing.
unequip_items: boolUnequip-items flag (UnequipItems).
unequip_h_item: boolUnequip-head-item flag (UnequipHItem).
animated_cut: boolAnimated-cutscene flag (AnimatedCut). When non-zero, the engine forces a global unpauseable state for the duration of the conversation.
old_hit_check: boolOld-hit-check flag (OldHitCheck).
starting_list: Vec<DlgLink>Starting links (point into entries by index).
entries: Vec<DlgNode>Entry nodes (NPC dialogue lines).
replies: Vec<DlgNode>Reply nodes (PC dialogue choices).
stunt_list: Vec<DlgStunt>Cutscene stunt actors.