read_fac

Function read_fac 

pub fn read_fac<R: Read>(reader: &mut R) -> Result<Fac, FacError>
Reads typed FAC data from a reader at the current stream position.

Errors

FacError::Gff when the stream is not a readable GFF, and FacError::UnsupportedFileType when it is a GFF of some other format, carrying the fourcc that was found.