read_ifo

Function read_ifo 

pub fn read_ifo<R: Read>(reader: &mut R) -> Result<Ifo, IfoError>
Reads typed IFO data from a reader at the current stream position.

Errors

IfoError::Gff when the stream is not a readable GFF, and IfoError::UnsupportedFileType when it is a GFF of some other format, carrying the fourcc that was found.