read_utc

Function read_utc 

pub fn read_utc<R: Read>(reader: &mut R) -> Result<Utc, UtcError>
Reads typed UTC data from a reader at the current stream position.

Errors

UtcError::Gff when the stream is not a readable GFF, and UtcError::UnsupportedFileType when it is a GFF of some other format, carrying the fourcc that was found.