read_utd

Function read_utd 

pub fn read_utd<R: Read>(reader: &mut R) -> Result<Utd, UtdError>
Reads typed UTD data from a reader at the current stream position.

Errors

UtdError::Gff when the stream is not a readable GFF, and UtdError::UnsupportedFileType when it is a GFF of some other format, carrying the fourcc that was found.