pub enum UteError {
UnsupportedFileType([u8; 4]),
TypeMismatch {
field: &'static str,
expected: &'static str,
},
Gff(GffBinaryError),
}Expand description
Errors produced while reading or writing typed UTE data.
Variants
UnsupportedFileType([u8; 4])
Source file type is not supported by this parser.
TypeMismatch
A required container field had an unexpected runtime type.
Fields
Gff(GffBinaryError)
Underlying GFF parser/writer error.