pub fn read_ute<R: Read>(reader: &mut R) -> Result<Ute, UteError>Expand description
Reads typed UTE data from a reader at the current stream position.
Errors
UteError::Gff when the stream is not a readable GFF, and
UteError::UnsupportedFileType when it is a GFF of some other format,
carrying the fourcc that was found.