pub fn read_uti<R: Read>(reader: &mut R) -> Result<Uti, UtiError>Expand description
Reads typed UTI data from a reader at the current stream position.
Errors
UtiError::Gff when the stream is not a readable GFF, and
UtiError::UnsupportedFileType when it is a GFF of some other format,
carrying the fourcc that was found.