read_utm

Function read_utm 

pub fn read_utm<R: Read>(reader: &mut R) -> Result<Utm, UtmError>
Reads typed UTM data from a reader at the current stream position.

Errors

UtmError::Gff when the stream is not a readable GFF, and UtmError::UnsupportedFileType when it is a GFF of some other format, carrying the fourcc that was found.