pub fn read_dlg<R: Read>(reader: &mut R) -> Result<Dlg, DlgError>Expand description
Reads typed DLG data from a reader at the current stream position.
Errors
DlgError::Gff when the stream is not a readable GFF, and
DlgError::UnsupportedFileType when it is a GFF of some other format,
carrying the fourcc that was found.