pub fn read_utp<R: Read>(reader: &mut R) -> Result<Utp, UtpError>Expand description
Reads typed UTP data from a reader at the current stream position.
Errors
UtpError::Gff when the stream is not a readable GFF, and
UtpError::UnsupportedFileType when it is a GFF of some other format,
carrying the fourcc that was found.