pub fn read_uts<R: Read>(reader: &mut R) -> Result<Uts, UtsError>Expand description
Reads typed UTS data from a reader at the current stream position.
Errors
UtsError::Gff when the stream is not a readable GFF, and
UtsError::UnsupportedFileType when it is a GFF of some other format,
carrying the fourcc that was found.