pub fn read_utt<R: Read>(reader: &mut R) -> Result<Utt, UttError>Expand description
Reads typed UTT data from a reader at the current stream position.
Errors
UttError::Gff when the stream is not a readable GFF, and
UttError::UnsupportedFileType when it is a GFF of some other format,
carrying the fourcc that was found.