pub fn read_utw<R: Read>(reader: &mut R) -> Result<Utw, UtwError>Expand description
Reads typed UTW data from a reader at the current stream position.
Errors
UtwError::Gff when the stream is not a readable GFF, and
UtwError::UnsupportedFileType when it is a GFF of some other format,
carrying the fourcc that was found.