pub struct Utw {Show 17 fields
pub template_resref: ResRef,
pub tag: String,
pub name: GffLocalizedString,
pub appearance_id: u8,
pub has_map_note: bool,
pub map_note_enabled: bool,
pub map_note: GffLocalizedString,
pub palette_id: u8,
pub comment: String,
pub linked_to: String,
pub description: GffLocalizedString,
pub x_position: f32,
pub y_position: f32,
pub z_position: f32,
pub x_orientation: f32,
pub y_orientation: f32,
pub z_orientation: f32,
}Expand description
Typed UTW model built from/to Gff data.
Fields
template_resref: ResRefWaypoint template resref (TemplateResRef).
tag: StringWaypoint tag (Tag).
name: GffLocalizedStringLocalized waypoint name (LocalizedName).
appearance_id: u8Waypoint appearance id (Appearance).
has_map_note: boolHas-map-note flag (HasMapNote).
map_note_enabled: boolMap-note-enabled flag (MapNoteEnabled). Engine ignores this if has_map_note is false.
map_note: GffLocalizedStringLocalized map note (MapNote). Engine ignores this if has_map_note is false.
palette_id: u8Palette id (PaletteID).
comment: StringToolset comment (Comment).
linked_to: StringDeprecated linked target (LinkedTo).
description: GffLocalizedStringDeprecated localized description (Description).
x_position: f32World X position (XPosition).
y_position: f32World Y position (YPosition).
z_position: f32World Z position (ZPosition).
x_orientation: f32Facing X component (XOrientation). Engine will normalize the orientation vector at runtime if its magnitude is not 1.0.
y_orientation: f32Facing Y component (YOrientation). Engine will normalize the orientation vector at runtime if its magnitude is not 1.0.
z_orientation: f32Facing Z component (ZOrientation). Engine will normalize the orientation vector at runtime if its magnitude is not 1.0.